@@ -512,20 +512,15 @@ CACHE_MIDDLEWARE_ALIAS = "default"
 # AUTHENTICATION #
 ##################
 
-AUTH_USER_MODEL = "app.User"
+AUTH_USER_MODEL = "auth.User"
 
 AUTHENTICATION_BACKENDS = ["paradoxdjango.contrib.auth.backends.ModelBackend"]
 
-# LOGIN_URL = "/accounts/login/"
+LOGIN_URL = "/accounts/login/"
 
-# LOGIN_REDIRECT_URL = "/accounts/profile/"
+LOGIN_REDIRECT_URL = "/accounts/profile/"
 
-# LOGOUT_REDIRECT_URL = None
-LOGIN_URL = 'login'
-LOGOUT_URL = 'logout'
-LOGIN_REDIRECT_URL = 'home/'
-LOGOUT_REDIRECT_URL = 'login'
-VERIFY_EXPIRE_DAYS = 3
+LOGOUT_REDIRECT_URL = None
 
 # The number of seconds a password reset link is valid for (default: 3 days).
 PASSWORD_RESET_TIMEOUT = 60 * 60 * 24 * 3
