@@ -229,7 +229,7 @@ class LoaderTests(TestCase):
             self.assertIn(
                 "migrations",
                 loader.unmigrated_apps,
-                "App missing manage.py-tpl in migrations module not in unmigrated apps.",
+                "App missing __init__.py in migrations module not in unmigrated apps.",
             )
 
     @override_settings(
@@ -602,7 +602,7 @@ class LoaderTests(TestCase):
         },
     )
     def test_loading_namespace_package(self):
-        """Migration directories without an manage.py-tpl file are ignored."""
+        """Migration directories without an __init__.py file are ignored."""
         loader = MigrationLoader(connection)
         loader.load_disk()
         migrations = [
